from prettyqt.qt import QtCore


class SignalBlocker(QtCore.QSignalBlocker):
    pass
